@@ -1,6 +1,6 @@
 __title__ = 'starbase.client.connection'
-__version__ = '0.1'
-__build__ = 0x000001
+__version__ = '0.2'
+__build__ = 0x000002
 __author__ = 'Artur Barseghyan'
 __all__ = ('Connection',)
 
@@ -8,27 +8,29 @@ from starbase.exceptions import ImproperlyConfigured
 from starbase.content_types import CONTENT_TYPES_DICT, CONTENT_TYPES, DEFAULT_CONTENT_TYPE
 from starbase.defaults import HOST, PORT, USER, PASSWORD, PERFECT_DICT
 from starbase.client.table import Table
-from starbase.client.http import HttpRequest
+from starbase.client.transport import HttpRequest
 
 class Connection(object):
     """
     Connection instance.
+
+    :param str host: Stargate host.
+    :param int port: Stargate port.
+    :param str user: Stargate user. Use this if your stargate is protected with HTTP basic
+        auth (to be used in combination with `password` argument).
+    :param str password: Stargate password (see comment to `user`).
+    :param bool secure: If set to True, HTTPS is used; otherwise - HTTP. Default value is False.
+    :param str content_type: Content type for data wrapping when communicating with the
+        Stargate. Possible options are: json.
+    :param bool perfect_dict: Global setting. If set to True, generally data will be returned as
+        perfect dict.
     """
     def __init__(self, host=HOST, port=PORT, user=USER, password=PASSWORD, secure=False, \
                  content_type=DEFAULT_CONTENT_TYPE, perfect_dict=PERFECT_DICT):
         """
-        Initialize a connection.
+        Creates a new connection instance.
 
-        :param str host: Stargate host.
-        :param int port: Stargate port.
-        :param str user: Stargate user. Use this if your stargate is protected with HTTP basic
-            auth (to be used in combination with `password` argument).
-        :param str password: Stargate password (see comment to `user`).
-        :param bool secure: If set to True, HTTPS is used; otherwise - HTTP. Default value is False.
-        :param str content_type: Content type for data wrapping when communicating with the
-            Stargate. Possible options are: json, xml, protobuf, but at the moment only json is
-            supported.
-        :param bool perfect_dict: Global setting. If set to True, generally data will be returned as perfect dict.
+        See docs above.
         """
         if not content_type in CONTENT_TYPES:
             raise ImproperlyConfigured(_("Invalid ``content_type`` %s value." % content_type))
@@ -111,7 +113,7 @@ class Connection(object):
         """
         Table list. Retrieves the list of available tables.
 
-        :param bool raw: If set to True raw result (JSON/XML/PHOTOBUF) is returned.
+        :param bool raw: If set to True raw result (JSON) is returned.
         :return list: Just a list of plain strings of table names, no Table instances.
         """
         response = HttpRequest(connection=self).get_response()
