@@ -292,14 +292,24 @@ class Table(object):
         return self._get(row, columns=columns, timestamp=timestamp, decode_content=True, \
                          number_of_versions=number_of_versions, raw=False, perfect_dict=perfect_dict)
 
-    def fetch_all_rows(self, with_row_id=False, raw=False, perfect_dict=None, flat=False):
+    def fetch_all_rows(self, with_row_id=False, raw=False, perfect_dict=None, flat=False, filter_string=None, scanner_config=''):
         """
-        Fetcjes all table rows.
+        Fetches all table rows.
 
         :param bool with_row_id: If set to True, returned along with row id.
         :param bool raw: If set to True, raw response is returned.
         :param bool perfect_dict: If set to True, a perfect dict struture is used for output data.
+        :param string filter_string: If set, applies the given filter string to the scanner.
         :returns list:
+
+        :example:
+        >>> filter_string = '{"type": "RowFilter", "op": "EQUAL", "comparator": '
+        >>>                 '{"type": "RegexStringComparator", "value": "^row_1.+" }}'
+        >>> rows = self.table.fetch_all_rows(
+        >>>            with_row_id = True,
+        >>>            perfect_dict = perfect_dict,
+        >>>            filter_string = row_filter_string
+        >>>            )
         """
         if not self.exists():
             return None
@@ -307,7 +317,9 @@ class Table(object):
         if perfect_dict is None:
             perfect_dict = self.connection.perfect_dict
 
-        res = self._scanner().results(perfect_dict=perfect_dict, with_row_id=with_row_id, raw=raw)
+        res = self._scanner(filter_string=filter_string, data=scanner_config) \
+                  .results(perfect_dict=perfect_dict, with_row_id=with_row_id, raw=raw)
+
         if flat:
             res = list(res)
 
@@ -413,7 +425,8 @@ class Table(object):
         """
         return self._put(row=row, columns=columns, timestamp=timestamp)
 
-    def _scanner(self, batch_size=None, start_row=None, end_row=None, start_time=None, end_time=None):
+    def _scanner(self, batch_size=None, start_row=None, end_row=None, start_time=None, end_time=None, \
+                 filter_string=None, data=''):
         """
         Creates a scanner instance.
 
@@ -422,10 +435,15 @@ class Table(object):
         :param str end_row:
         :param start_time:
         :param end_time:
+        :param str filter_string:
         :return starbase.client.Scanner: Creates and returns a class::`starbase.client.Scanner` instance.
         """
         url = '%s/scanner' % self.name
-        response = HttpRequest(connection=self.connection, url=url, method=PUT).get_response()
+
+        if filter_string is not None:
+            data = {"filter": filter_string}
+
+        response = HttpRequest(connection=self.connection, url=url, data=data, method=PUT).get_response()
         scanner_url = response.raw.headers.get('location')
 
         return Scanner(table=self, url=scanner_url)
